/// html_sql/py_sql impled
#[macro_export]
macro_rules! impled {
    ()=>{}
}